@@ -18,7 +18,8 @@ def main():
 
 @main.command()
 @click.argument('pid')
-def init(pid):
+@click.argument('type', default='web')
+def init(pid, type):
     """Initiate LS project by creating config file in pwd directory where command being used from. You need to provide project unique id to be able to use LitStrings cloud translation management services. If you plan to use LS as open source library without need of our cloud services, you can use any value as PID """
     pwd = os.getcwd()
     config = configparser.ConfigParser()
@@ -30,6 +31,7 @@ def init(pid):
         config.add_section('project_data')
         config.set('project_data', 'pid', pid)
         config.set('project_data', 'path', pwd)
+        config.set('project_data', 'type', type)
         with open('.litstrings', 'w') as configfile:    # save
             config.write(configfile)
         response = 'Project initiated'
@@ -90,7 +92,7 @@ def languages_remote():
         url_format = lsUrl+'api/v1/project/'+config['project_data']['pid']+'/languages'
         response = requests.get(url_format).json()
         for x in response:
-            print x
+            print(x)
     else:
         response = 'Project not yet initiated'
 
